@@ -64,6 +64,22 @@ models = {
         "additionalProperties": False,
         "required": ["action", "id"]
     },
+    "read_run_artifact_input": {
+        "type": "object",
+        "properties": {
+            "action": {
+                "type": "string",
+            },
+            "id": {
+                "type": "integer"
+            },
+            "artifact_name": {
+                "type": "string"
+            }
+        },
+        "additionalProperties": False,
+        "required": ["action", "id", "artifact_name"]
+    },
 }
 
 types = {
