@@ -13,6 +13,8 @@ from unicorncommon.server_status import SERVER_STATUS
 from .api_input import validate_model
 from unicorncommon.dbagent_client import DBAgentException
 
+# Limit the size client can read to 12MB
+MAX_FILE_SIZE = 12*1024*1024
 
 class Executor:
     def __init__(self, *, dbagent_client, base_data_dir, node_id, cfg_dir):
@@ -119,6 +121,45 @@ class Executor:
                         logger.exception(f"{log_prefix}: failed to delete run({run['id']}), error: {str(e)}")
 
 
+    # read file
+    def handle_request_read_run_artifact(self, request):
+        log_prefix = "handle_request_read_run_artifact"
+        # request example
+        # {
+        #     "action": "read-run-artifact",
+        #     "id": 123,
+        #     "artifact_name": "foo"
+        # }
+        try:
+            validate_model('read_run_artifact_input', request)
+        except ValidationError as e:
+            logger.exception(f"{log_prefix}: validation error, schema: read_run_artifact_input, error: {str(e)}")
+            return {
+                "status": SERVER_STATUS.INVALID_REQUEST_SCHEMA.value,
+                "message": str(e)
+            }
+
+        id = request["id"]
+        run_dir = os.path.join(self.runs_dir, str(id))
+        filename = os.path.join(run_dir, request['artifact_name'])
+        try:
+            filesize = os.path.getsize(filename)
+            if filesize >= MAX_FILE_SIZE:
+                logger.exception(f"{log_prefix}: file: {filename}, size: {filesize}, it is too big")
+                return {
+                    "status": SERVER_STATUS.FILE_TOO_BIG.value,
+                }
+            with open(filename, "rt") as f:
+                return {
+                    "status": SERVER_STATUS.OK.value,
+                    "content": f.read(),
+                }
+        except OSError as e:
+            logger.exception(f"{log_prefix}: unabel to read file {filename}, error: {str(e)}")
+            return {
+                "status": SERVER_STATUS.FILE_READ_FAILURE.value,
+            }
+
     # execute an application using task
     def handle_request_run_task(self, request):
         log_prefix = "handle_request_run_task"
@@ -301,6 +342,8 @@ class Executor:
             response = self.handle_request_run_task(request)
         elif action == "stop-run":
             response = self.handle_request_stop_run(request)
+        elif action == "read-run-artifact":
+            response = self.handle_request_read_run_artifact(request)
         else:
             response = {"status": SERVER_STATUS.INVALID_ACTION.value}
         return response
