@@ -20,4 +20,5 @@ class SERVER_STATUS(Enum):
     NODE_IS_NOT_ACTIVE          = 14
     NODE_IS_NOT_UP              = 15
 
-
+    FILE_READ_FAILURE           = 16        # unable to read a file
+    FILE_TOO_BIG                = 17        # file is too big
